Module context
dial
2.2.0
Module context
Module Items
Functions
In dial::
iteration
dial
::
iteration
Module
context
Functions

gather_
context
gather_
context_
without_
signs
generate_
subagent_
prompt
Generate a fresh context prompt for spawning a sub-agent (orchestrator mode). This produces a self-contained prompt that can be used to spawn a fresh AI session.